@@ -110,6 +110,9 @@ static uint64_t conftimer = 0;
 static int menuactive = 0;
 static int discard_keyup = 0;
 
+// Keyboard Mode
+static int kbmode = 0; // Default to Keyboard Mode (hotkeys disabled) off
+
 void jgrf_input_config_enable(int e) {
     confactive = e;
 }
@@ -682,8 +685,18 @@ void jgrf_input_handler(SDL_Event *event) {
         return;
     }
 
+    // Check if we need to change keyboard mode
+    if ((event->key.keysym.mod & KMOD_SHIFT) &&
+        (event->key.keysym.scancode == SDL_SCANCODE_TAB)) {
+        if (event->type == SDL_KEYUP) {
+            kbmode ^= 1;
+            jgrf_log(JG_LOG_SCR, "Hotkeys %s", kbmode ? "Disabled" : "Enabled");
+        }
+        return;
+    }
+
     // This needs to be fixed and worked into the rest of the system one day...
-    if (event->type == SDL_KEYUP || event->type == SDL_KEYDOWN) {
+    if (!kbmode && (event->type == SDL_KEYUP || event->type == SDL_KEYDOWN)) {
         switch (event->key.keysym.scancode) {
             case SDL_SCANCODE_ESCAPE: {
                 jgrf_schedule_quit();
@@ -775,7 +788,7 @@ void jgrf_input_handler(SDL_Event *event) {
                     jgrf_input_menu_enable(1);
                     jgrf_menu_display();
                 }
-                break;
+                return;
             }
             default: {
                 break;
